@@ -2,16 +2,16 @@
 
 #include "kdialogd.h"
 #include <iostream>
-#include <kdiroperator.h>
+#include <tdediroperator.h>
 #include <kuniqueapplication.h>
 #include <tqsocketnotifier.h>
-#include <kio/netaccess.h>
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdeio/netaccess.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kurlcombobox.h>
 #ifdef USE_KWIN
-#include <kwin.h>
+#include <twin.h>
 #else
 #include <X11/Xlib.h>
 #endif
@@ -21,15 +21,15 @@
 #include <sys/errno.h>
 #include <ksockaddr.h>
 #include <kdebug.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <tqtimer.h>
 #ifdef KDIALOGD_APP
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
+#include <tdecmdlineargs.h>
+#include <tdeaboutdata.h>
 #endif
 #include <fstream>
 
-KConfig *KDialogD::theirConfig=NULL;
+TDEConfig *KDialogD::theirConfig=NULL;
 
 #define CFG_KEY_DIALOG_SIZE "KDialogDSize"
 #define CFG_TIMEOUT_GROUP   "General"
@@ -43,7 +43,7 @@ static TQString groupName(const TQString &app, bool fileDialog=true)
    return TQString(fileDialog ? "KFileDialog " : "KDirSelectDialog ")+app;
 }
 
-// from kdebase/kdesu
+// from tdebase/tdesu
 static int createSocket()
 {
     int         sockitsFd;
@@ -132,7 +132,7 @@ static void urls2Local(KURL::List &urls, TQStringList &items, TQWidget *parent)
         else
         {
 #if KDE_IS_VERSION(3, 5, 0)
-            KURL url(KIO::NetAccess::mostLocalURL(*it, parent));
+            KURL url(TDEIO::NetAccess::mostLocalURL(*it, parent));
 
             if(url.isLocalFile())
                 items.append(url.path());
@@ -170,10 +170,10 @@ KDialogD::KDialogD(TQObject *parent)
             f.close();
         }
         if(!theirConfig)
-            theirConfig=new KConfig("kdialogdrc", false, false);
+            theirConfig=new TDEConfig("kdialogdrc", false, false);
 
         connect(new TQSocketNotifier(itsFd, TQSocketNotifier::Read, this),
-                TQT_SIGNAL(activated(int)), this, TQT_SLOT(newConnection()));
+                TQ_SIGNAL(activated(int)), this, TQ_SLOT(newConnection()));
 
 #ifdef KDIALOGD_APP
         if(theirConfig->hasGroup(CFG_TIMEOUT_GROUP))
@@ -187,7 +187,7 @@ KDialogD::KDialogD(TQObject *parent)
 
         kdDebug() << "Timeout:" << itsTimeoutVal << endl;
         if(itsTimeoutVal)
-            connect(itsTimer=new TQTimer(this), TQT_SIGNAL(timeout()), this, TQT_SLOT(timeout()));
+            connect(itsTimer=new TQTimer(this), TQ_SIGNAL(timeout()), this, TQ_SLOT(timeout()));
 #endif
     }
 }
@@ -234,8 +234,8 @@ void KDialogD::newConnection()
                     itsTimer->stop();
 #endif
                 connect(new KDialogDClient(connectedFD, appName, this),
-                        TQT_SIGNAL(error(KDialogDClient *)),
-                        this, TQT_SLOT(deleteConnection(KDialogDClient *)));
+                        TQ_SIGNAL(error(KDialogDClient *)),
+                        this, TQ_SLOT(deleteConnection(KDialogDClient *)));
             }
         }
     }
@@ -280,8 +280,8 @@ KDialogDClient::KDialogDClient(int sock, const TQString &an, TQObject *parent)
                 itsAppName(an)
 {
     kdDebug() << "new client..." << itsAppName << " (" << itsFd << ")" << endl;
-    connect(new TQSocketNotifier(itsFd, TQSocketNotifier::Read, this), TQT_SIGNAL(activated(int)), this, TQT_SLOT(read()));
-    connect(new TQSocketNotifier(itsFd, TQSocketNotifier::Exception, this), TQT_SIGNAL(activated(int)), this, TQT_SLOT(close()));
+    connect(new TQSocketNotifier(itsFd, TQSocketNotifier::Read, this), TQ_SIGNAL(activated(int)), this, TQ_SLOT(read()));
+    connect(new TQSocketNotifier(itsFd, TQSocketNotifier::Exception, this), TQ_SIGNAL(activated(int)), this, TQ_SLOT(close()));
 }
 
 KDialogDClient::~KDialogDClient()
@@ -485,14 +485,14 @@ void KDialogDClient::initDialog(const TQString &caption, KDialogBase *d, unsigne
 #else
         XWindowAttributes attr;
         int               rx, ry;
-        Window            junkwin;
+        Window            juntwin;
 
-        XSetTransientForHint(qt_xdisplay(), itsDlg->winId(), xid);
-        if(XGetWindowAttributes(qt_xdisplay(), xid, &attr))
+        XSetTransientForHint(tqt_xdisplay(), itsDlg->winId(), xid);
+        if(XGetWindowAttributes(tqt_xdisplay(), xid, &attr))
         {
-            XTranslateCoordinates(qt_xdisplay(), xid, attr.root,
+            XTranslateCoordinates(tqt_xdisplay(), xid, attr.root,
                                   -attr.border_width, -16,
-                                  &rx, &ry, &junkwin);
+                                  &rx, &ry, &juntwin);
 
             rx=(rx+(attr.width/2))-(itsDlg->width()/2);
             if(rx<0)
@@ -505,8 +505,8 @@ void KDialogDClient::initDialog(const TQString &caption, KDialogBase *d, unsigne
 #endif
     }
 
-    connect(itsDlg, TQT_SIGNAL(ok(const TQStringList &)), this, TQT_SLOT(ok(const TQStringList &)));
-    connect(itsDlg, TQT_SIGNAL(finished()), this, TQT_SLOT(finished()));
+    connect(itsDlg, TQ_SIGNAL(ok(const TQStringList &)), this, TQ_SLOT(ok(const TQStringList &)));
+    connect(itsDlg, TQ_SIGNAL(finished()), this, TQ_SLOT(finished()));
     itsDlg->show();
 }
 
@@ -583,12 +583,12 @@ void KDialogDFileDialog::slotOk()
             good=false;
         }
         else if(itsConfirmOw && KFileDialog::Saving==operationMode())
-            good=!KIO::NetAccess::exists(urls.first(), false, this) ||
+            good=!TDEIO::NetAccess::exists(urls.first(), false, this) ||
                  KMessageBox::Continue==KMessageBox::warningContinueCancel(this,
                                             i18n("File %1 exists.\nDo you want to replace it?")
                                                  .arg(urls.first().prettyURL()),
                                             i18n("File Exists"),
-                                            KGuiItem(i18n("Replace"), "filesaveas"), TQString(),
+                                            KGuiItem(i18n("Replace"), "document-save-as"), TQString(),
                                             KMessageBox::Notify|KMessageBox::PlainCaption);
 
         if(good)
@@ -682,14 +682,14 @@ void KDialogDDirSelectDialog::slotOk()
 }
 
 #ifdef KDIALOGD_APP
-static KAboutData aboutData("kdialogd3", I18N_NOOP("KDialog Daemon"), VERSION,
-                            I18N_NOOP("Use KDE dialogs from non-KDE apps."),
-                            KAboutData::License_GPL,
+static TDEAboutData aboutData("kdialogd3", I18N_NOOP("KDialog Daemon"), VERSION,
+                            I18N_NOOP("Use TDE dialogs from non-TDE apps."),
+                            TDEAboutData::License_GPL,
                             I18N_NOOP("(c) Craig Drummond, 2006-2007"));
 
 int main(int argc, char **argv)
 {
-    KCmdLineArgs::init(argc, argv, &aboutData);
+    TDECmdLineArgs::init(argc, argv, &aboutData);
 
     KUniqueApplication *app=new KUniqueApplication;
     KDialogD           kdialogd;
